pub struct Label { /* private fields */ }Expand description
Convenience-based struct converting typical AoC node labels consisting of numbers and letters to a numeric representation, saveing all that tedious mucking about with lifetimes.
Note that Labels are case-insensitive.
Implementations